<?php
/**
 * Admin functions.
 *
 * @package Restaurantz
 */

add_action( 'admin_menu', 'restaurantz_admin_menu_page' );

/**
 * Register admin page.
 *
 * @since 1.0.0
 */
function restaurantz_admin_menu_page() {
	add_theme_page(
		__( 'Restaurantz Pro', 'restaurantz' ),
		__( 'Demo Content', 'restaurantz' ),
		'manage_options',
		'restaurantz_admin_page',
		'restaurantz_do_admin_page'
	);
}


/**
 * Render admin page.
 *
 * @since 1.0.0
 */
function restaurantz_do_admin_page() {
	?>
	<div class="wrap">
		<h1><?php esc_html_e( 'Restaurantz Pro', 'restaurantz' ); ?></h1>
		<?php
		$message = get_transient( 'restaurantz_message' );
		delete_transient( 'restaurantz_message' );
		?>
		<?php if ( ! empty( $message ) ) : ?>
			<div class="updated settings-error notice is-dismissible">
				<p><?php echo $message; ?></p>
			</div>
		<?php endif ?>

		<h2><?php esc_html_e( 'Demo Content', 'restaurantz' ); ?></h2>
		<?php if ( ! defined( 'SITEORIGIN_PANELS_VERSION' ) || ! defined( 'SOW_BUNDLE_VERSION' ) ) : ?>
			<div class="extra-message">
				<p>
					<strong><?php esc_html_e( 'Please activate following plugins to proceed with importing of demo content.', 'restaurantz' ); ?></strong>
					<?php if ( isset( $GLOBALS['tgmpa'] ) ) : ?>
						<?php $tgmpa_instance = $GLOBALS['tgmpa']->get_instance(); ?>
							<strong><a href="<?php echo esc_url( $tgmpa_instance->get_tgmpa_url() ); ?>"><?php esc_html_e( 'Install Plugins', 'restaurantz' ); ?></a></strong>
					<?php endif ?>
				</p>
				<ul>
					<li><?php esc_html_e( 'Page Builder by SiteOrigin', 'restaurantz' ); ?></li>
					<li><?php esc_html_e( 'SiteOrigin Widgets Bundle', 'restaurantz' ); ?></li>
				</ul>
			</div><!-- .extra-message -->
		<?php else : ?>
			<p>
				<a href="<?php echo wp_nonce_url( admin_url( 'themes.php?page=restaurantz_admin_page' ), 'restaurantz_import_demo_content', 'restaurantz_import_demo_content_nonce' ); ?>" class="button button-primary"><?php esc_html_e( 'Import Demo Content', 'restaurantz' ); ?></a>
			</p>
			<p><strong><?php esc_html_e( 'This will create three pages: Home, About and Contact if not already exists. If pages already exist then new page will NOT be created.', 'restaurantz' ); ?></strong></p>
		<?php endif ?>
	</div><!-- .wrap -->
	<?php
}

add_action( 'admin_init', 'restaurantz_import_demo_content_callback' );

/**
 * Callback for demo content import.
 *
 * @since 1.0.0
 */
function restaurantz_import_demo_content_callback() {

	if ( isset( $_REQUEST['restaurantz_import_demo_content_nonce'] ) ) {
	    if ( wp_verify_nonce( $_REQUEST['restaurantz_import_demo_content_nonce'], 'restaurantz_import_demo_content' ) ) {
	        // Nonce is valid; proceed now.
	    	$import_status = restaurantz_import_sample_content();
	    }
	    $message = '';
	    if ( true === $import_status ) {
	    	$message = __( 'Content imported successfully.', 'restaurantz' );
	    	$message .= ' <a href="' . esc_url( home_url( '/' ) ) . '" target="_blank">' . __( 'View Site', 'restaurantz' ) . '</a>';
	    } else {
	    	$message = __( 'Error while importing demo content.', 'restaurantz' );
	    }
	    set_transient( 'restaurantz_message', $message );
	    wp_redirect( admin_url( 'themes.php?page=restaurantz_admin_page' ) );
	    exit;
	}

}

/**
 * Import sample content.
 *
 * @since 1.0.0
 */
function restaurantz_import_sample_content() {
	$output = false;

	$pages = array(
		'restaurantz-home' => array(
			'title' => 'Home',
			'options' => array(
				'set_front_page' => true,
				'builder_layout' => 'restaurantz-home-page',
			),
			'meta' => array(
				'theme_meta' => array(
					'post_layout'         => 'no-sidebar',
					'disable_banner_area' => '1',
					'disable_breadcrumb'  => true,
				),
				'post_meta' => array(
					'restaurantz-disable-overlap' => false,
				),
			),
		),
		'restaurantz-contact' => array(
			'title' => 'Contact',
			'options' => array(
				'set_front_page' => false,
				'builder_layout' => 'restaurantz-contact',
			),
			'meta' => array(
				'theme_meta' => array(
					'post_layout'        => 'no-sidebar',
					'disable_breadcrumb' => true,
				),
				'post_meta' => array(
					'restaurantz-disable-overlap' => false,
				),
			),
		),
		'restaurantz-about' => array(
			'title' => 'About',
			'options' => array(
				'set_front_page' => false,
				'builder_layout' => 'restaurantz-about',
			),
			'meta' => array(
				'theme_meta' => array(
					'post_layout'        => 'no-sidebar',
					'disable_breadcrumb' => true,
				),
				'post_meta' => array(
					'restaurantz-disable-overlap' => false,
				),
			),
		),
	);

	$page_ids = array();
	$new_front_page_id = '';

	foreach ( $pages as $page_key => $page ) {
		$page_exists = get_page_by_title( $page['title'] );
		if ( ! $page_exists ) {
			// No page; create now.
			$my_page = array(
				'post_title'   => $page['title'],
				'post_content' => '',
				'post_status'  => 'publish',
				'post_type'    => 'page',
			);
			// Create page.
			$page_id = wp_insert_post( $my_page );
			if ( ! is_wp_error( $page_id ) ) {
				// Push new page id to the array.
				$page_ids[] = $page_id;

				// Set static front page.
				if ( isset( $page['options']['set_front_page'] ) && 1 === absint( $page['options']['set_front_page'] ) ) {
					update_option( 'show_on_front', 'page' );
					update_option( 'page_on_front', $page_id );
					$new_front_page_id = $page_id;
				}
				// Update theme meta.
				if ( isset( $page['meta']['theme_meta'] ) && ! empty( $page['meta']['theme_meta'] ) ) {
					update_post_meta( $page_id, 'restaurantz_theme_settings', $page['meta']['theme_meta'] );
				}
				// Update post meta.
				if ( isset( $page['meta']['post_meta'] ) && ! empty( $page['meta']['post_meta'] ) ) {
					foreach ( $page['meta']['post_meta'] as $meta_key => $meta_value ) {
						update_post_meta( $page_id, $meta_key, $meta_value );
					}
				}
				// Import builder layout.
				if ( isset( $page['options']['builder_layout'] ) && ! empty( $page['options']['builder_layout'] ) ) {
					$layouts = apply_filters( 'siteorigin_panels_prebuilt_layouts', array() );
					$builder_layout = $layouts[ $page['options']['builder_layout'] ];
					$panels_data = $builder_layout;
					$panels_data['widgets'] = siteorigin_panels_process_raw_widgets( $panels_data['widgets'] );
					$panels_data = siteorigin_panels_styles_sanitize_all( $panels_data );
					update_post_meta( $page_id, 'panels_data', $panels_data );
				}
			}
		}
		else {
			// Push page id (which already exists) to the array.
			$page_ids[] = $page_exists->ID;
		}
	}

	// Creating navigation menu.
	$menu_name = 'Restaurantz Menu';
	$menu_exists = wp_get_nav_menu_object( $menu_name );
	if ( ! empty( $page_ids) && ! $menu_exists ) {
		if ( absint( $new_front_page_id ) > 0 ) {
			// Remove front page id from array.
			$page_ids = array_diff( $page_ids, array( $new_front_page_id ) );
		}
		$menu_id = wp_create_nav_menu( $menu_name );
		$arr_menu_home = array(
			'menu-item-title'  => __( 'Home', 'restaurantz' ),
			'menu-item-url'    => esc_url( home_url( '/' ) ),
			'menu-item-status' => 'publish',
			'menu-item-type'   => 'custom',
		);
		wp_update_nav_menu_item( $menu_id, 0, $arr_menu_home );

		if ( ! empty( $page_ids ) ) {
			foreach ( $page_ids as $pitem ) {
				$temp = array(
					'menu-item-status'    => 'publish',
					'menu-item-type'      => 'post_type',
					'menu-item-object'    => 'page',
					'menu-item-object-id' => $pitem,
				);
				wp_update_nav_menu_item( $menu_id, 0, $temp );
			}
		}
		// Set to menu location.
		$locations = get_theme_mod( 'nav_menu_locations' );
		$locations['primary'] = $menu_id;
		set_theme_mod( 'nav_menu_locations', $locations );

	}

	$output = true;
	return $output;

}

/**
 * Load admin scripts.
 *
 * @since 1.0.0
 *
 * @param string $hook Current page hook.
 */
function restaurantz_load_admin_scripts( $hook ) {

	if ( 'appearance_page_restaurantz_admin_page' === $hook ) {

		$min = defined( 'SCRIPT_DEBUG' ) && SCRIPT_DEBUG ? '' : '.min';

		wp_enqueue_style( 'restaurantz-admin', get_template_directory_uri() . '/css/admin' . $min . '.css', false, '2.0.0' );

	}

}
add_action( 'admin_enqueue_scripts', 'restaurantz_load_admin_scripts' );
